# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/listener/proxy_protocol/v3/proxy_protocol.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/listener/proxy_protocol/v3/proxy_protocol.proto',
  package='envoy.extensions.filters.listener.proxy_protocol.v3',
  syntax='proto3',
  serialized_options=b'\nAio.envoyproxy.envoy.extensions.filters.listener.proxy_protocol.v3B\022ProxyProtocolProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nHenvoy/extensions/filters/listener/proxy_protocol/v3/proxy_protocol.proto\x12\x33\x65nvoy.extensions.filters.listener.proxy_protocol.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xfc\x02\n\rProxyProtocol\x12V\n\x05rules\x18\x01 \x03(\x0b\x32G.envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol.Rule\x1a@\n\x0cKeyValuePair\x12\x1a\n\x12metadata_namespace\x18\x01 \x01(\t\x12\x14\n\x03key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1a\x8b\x01\n\x04Rule\x12\x1a\n\x08tlv_type\x18\x01 \x01(\rB\x08\xfa\x42\x05*\x03\x10\x80\x02\x12g\n\x0eon_tlv_present\x18\x02 \x01(\x0b\x32O.envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol.KeyValuePair:C\x9a\xc5\x88\x1e>\n<envoy.config.filter.listener.proxy_protocol.v2.ProxyProtocolBa\nAio.envoyproxy.envoy.extensions.filters.listener.proxy_protocol.v3B\x12ProxyProtocolProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_PROXYPROTOCOL_KEYVALUEPAIR = _descriptor.Descriptor(
  name='KeyValuePair',
  full_name='envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol.KeyValuePair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata_namespace', full_name='envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol.KeyValuePair.metadata_namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol.KeyValuePair.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=326,
  serialized_end=390,
)

_PROXYPROTOCOL_RULE = _descriptor.Descriptor(
  name='Rule',
  full_name='envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol.Rule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tlv_type', full_name='envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol.Rule.tlv_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005*\003\020\200\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_tlv_present', full_name='envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol.Rule.on_tlv_present', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=532,
)

_PROXYPROTOCOL = _descriptor.Descriptor(
  name='ProxyProtocol',
  full_name='envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rules', full_name='envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol.rules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PROXYPROTOCOL_KEYVALUEPAIR, _PROXYPROTOCOL_RULE, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036>\n<envoy.config.filter.listener.proxy_protocol.v2.ProxyProtocol',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=601,
)

_PROXYPROTOCOL_KEYVALUEPAIR.containing_type = _PROXYPROTOCOL
_PROXYPROTOCOL_RULE.fields_by_name['on_tlv_present'].message_type = _PROXYPROTOCOL_KEYVALUEPAIR
_PROXYPROTOCOL_RULE.containing_type = _PROXYPROTOCOL
_PROXYPROTOCOL.fields_by_name['rules'].message_type = _PROXYPROTOCOL_RULE
DESCRIPTOR.message_types_by_name['ProxyProtocol'] = _PROXYPROTOCOL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProxyProtocol = _reflection.GeneratedProtocolMessageType('ProxyProtocol', (_message.Message,), {

  'KeyValuePair' : _reflection.GeneratedProtocolMessageType('KeyValuePair', (_message.Message,), {
    'DESCRIPTOR' : _PROXYPROTOCOL_KEYVALUEPAIR,
    '__module__' : 'envoy.extensions.filters.listener.proxy_protocol.v3.proxy_protocol_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol.KeyValuePair)
    })
  ,

  'Rule' : _reflection.GeneratedProtocolMessageType('Rule', (_message.Message,), {
    'DESCRIPTOR' : _PROXYPROTOCOL_RULE,
    '__module__' : 'envoy.extensions.filters.listener.proxy_protocol.v3.proxy_protocol_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol.Rule)
    })
  ,
  'DESCRIPTOR' : _PROXYPROTOCOL,
  '__module__' : 'envoy.extensions.filters.listener.proxy_protocol.v3.proxy_protocol_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol)
  })
_sym_db.RegisterMessage(ProxyProtocol)
_sym_db.RegisterMessage(ProxyProtocol.KeyValuePair)
_sym_db.RegisterMessage(ProxyProtocol.Rule)


DESCRIPTOR._options = None
_PROXYPROTOCOL_KEYVALUEPAIR.fields_by_name['key']._options = None
_PROXYPROTOCOL_RULE.fields_by_name['tlv_type']._options = None
_PROXYPROTOCOL._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/matcher/v3/http_inputs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/type/matcher/v3/http_inputs.proto',
  package='envoy.type.matcher.v3',
  syntax='proto3',
  serialized_options=b'\n#io.envoyproxy.envoy.type.matcher.v3B\017HttpInputsProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'envoy/type/matcher/v3/http_inputs.proto\x12\x15\x65nvoy.type.matcher.v3\x1a\x1dudpa/annotations/status.proto\"2\n\x1bHttpRequestHeaderMatchInput\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\"3\n\x1cHttpResponseHeaderMatchInput\x12\x13\n\x0bheader_name\x18\x01 \x01(\tB@\n#io.envoyproxy.envoy.type.matcher.v3B\x0fHttpInputsProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_HTTPREQUESTHEADERMATCHINPUT = _descriptor.Descriptor(
  name='HttpRequestHeaderMatchInput',
  full_name='envoy.type.matcher.v3.HttpRequestHeaderMatchInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header_name', full_name='envoy.type.matcher.v3.HttpRequestHeaderMatchInput.header_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=147,
)


_HTTPRESPONSEHEADERMATCHINPUT = _descriptor.Descriptor(
  name='HttpResponseHeaderMatchInput',
  full_name='envoy.type.matcher.v3.HttpResponseHeaderMatchInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header_name', full_name='envoy.type.matcher.v3.HttpResponseHeaderMatchInput.header_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=200,
)

DESCRIPTOR.message_types_by_name['HttpRequestHeaderMatchInput'] = _HTTPREQUESTHEADERMATCHINPUT
DESCRIPTOR.message_types_by_name['HttpResponseHeaderMatchInput'] = _HTTPRESPONSEHEADERMATCHINPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HttpRequestHeaderMatchInput = _reflection.GeneratedProtocolMessageType('HttpRequestHeaderMatchInput', (_message.Message,), {
  'DESCRIPTOR' : _HTTPREQUESTHEADERMATCHINPUT,
  '__module__' : 'envoy.type.matcher.v3.http_inputs_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.matcher.v3.HttpRequestHeaderMatchInput)
  })
_sym_db.RegisterMessage(HttpRequestHeaderMatchInput)

HttpResponseHeaderMatchInput = _reflection.GeneratedProtocolMessageType('HttpResponseHeaderMatchInput', (_message.Message,), {
  'DESCRIPTOR' : _HTTPRESPONSEHEADERMATCHINPUT,
  '__module__' : 'envoy.type.matcher.v3.http_inputs_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.matcher.v3.HttpResponseHeaderMatchInput)
  })
_sym_db.RegisterMessage(HttpResponseHeaderMatchInput)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/trace/v3/zipkin.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/trace/v3/zipkin.proto',
  package='envoy.config.trace.v3',
  syntax='proto3',
  serialized_options=b'\n#io.envoyproxy.envoy.config.trace.v3B\013ZipkinProtoP\001\362\230\376\217\005)\022\'envoy.extensions.tracers.zipkin.v4alpha\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"envoy/config/trace/v3/zipkin.proto\x12\x15\x65nvoy.config.trace.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xcc\x03\n\x0cZipkinConfig\x12\"\n\x11\x63ollector_cluster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12#\n\x12\x63ollector_endpoint\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x17\n\x0ftrace_id_128bit\x18\x03 \x01(\x08\x12\x37\n\x13shared_span_context\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12`\n\x1a\x63ollector_endpoint_version\x18\x05 \x01(\x0e\x32<.envoy.config.trace.v3.ZipkinConfig.CollectorEndpointVersion\x12\x1a\n\x12\x63ollector_hostname\x18\x06 \x01(\t\"x\n\x18\x43ollectorEndpointVersion\x12\x33\n%DEPRECATED_AND_UNAVAILABLE_DO_NOT_USE\x10\x00\x1a\x08\x08\x01\xa8\xf7\xb4\x8b\x02\x01\x12\r\n\tHTTP_JSON\x10\x01\x12\x0e\n\nHTTP_PROTO\x10\x02\x12\x08\n\x04GRPC\x10\x03:)\x9a\xc5\x88\x1e$\n\"envoy.config.trace.v2.ZipkinConfigBk\n#io.envoyproxy.envoy.config.trace.v3B\x0bZipkinProtoP\x01\xf2\x98\xfe\x8f\x05)\x12\'envoy.extensions.tracers.zipkin.v4alpha\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,envoy_dot_annotations_dot_deprecation__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_ZIPKINCONFIG_COLLECTORENDPOINTVERSION = _descriptor.EnumDescriptor(
  name='CollectorEndpointVersion',
  full_name='envoy.config.trace.v3.ZipkinConfig.CollectorEndpointVersion',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEPRECATED_AND_UNAVAILABLE_DO_NOT_USE', index=0, number=0,
      serialized_options=b'\010\001\250\367\264\213\002\001',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP_JSON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTP_PROTO', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRPC', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=551,
  serialized_end=671,
)
_sym_db.RegisterEnumDescriptor(_ZIPKINCONFIG_COLLECTORENDPOINTVERSION)


_ZIPKINCONFIG = _descriptor.Descriptor(
  name='ZipkinConfig',
  full_name='envoy.config.trace.v3.ZipkinConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='collector_cluster', full_name='envoy.config.trace.v3.ZipkinConfig.collector_cluster', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collector_endpoint', full_name='envoy.config.trace.v3.ZipkinConfig.collector_endpoint', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trace_id_128bit', full_name='envoy.config.trace.v3.ZipkinConfig.trace_id_128bit', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shared_span_context', full_name='envoy.config.trace.v3.ZipkinConfig.shared_span_context', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collector_endpoint_version', full_name='envoy.config.trace.v3.ZipkinConfig.collector_endpoint_version', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collector_hostname', full_name='envoy.config.trace.v3.ZipkinConfig.collector_hostname', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ZIPKINCONFIG_COLLECTORENDPOINTVERSION,
  ],
  serialized_options=b'\232\305\210\036$\n\"envoy.config.trace.v2.ZipkinConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=254,
  serialized_end=714,
)

_ZIPKINCONFIG.fields_by_name['shared_span_context'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_ZIPKINCONFIG.fields_by_name['collector_endpoint_version'].enum_type = _ZIPKINCONFIG_COLLECTORENDPOINTVERSION
_ZIPKINCONFIG_COLLECTORENDPOINTVERSION.containing_type = _ZIPKINCONFIG
DESCRIPTOR.message_types_by_name['ZipkinConfig'] = _ZIPKINCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ZipkinConfig = _reflection.GeneratedProtocolMessageType('ZipkinConfig', (_message.Message,), {
  'DESCRIPTOR' : _ZIPKINCONFIG,
  '__module__' : 'envoy.config.trace.v3.zipkin_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.trace.v3.ZipkinConfig)
  })
_sym_db.RegisterMessage(ZipkinConfig)


DESCRIPTOR._options = None
_ZIPKINCONFIG_COLLECTORENDPOINTVERSION.values_by_name["DEPRECATED_AND_UNAVAILABLE_DO_NOT_USE"]._options = None
_ZIPKINCONFIG.fields_by_name['collector_cluster']._options = None
_ZIPKINCONFIG.fields_by_name['collector_endpoint']._options = None
_ZIPKINCONFIG._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/grpc_http1_reverse_bridge/v3/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/grpc_http1_reverse_bridge/v3/config.proto',
  package='envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3',
  syntax='proto3',
  serialized_options=b'\nHio.envoyproxy.envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3B\013ConfigProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nGenvoy/extensions/filters/http/grpc_http1_reverse_bridge/v3/config.proto\x12:envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x9c\x01\n\x0c\x46ilterConfig\x12\x1d\n\x0c\x63ontent_type\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1c\n\x14withhold_grpc_frames\x18\x02 \x01(\x08:O\x9a\xc5\x88\x1eJ\nHenvoy.config.filter.http.grpc_http1_reverse_bridge.v2alpha1.FilterConfig\"\x81\x01\n\x14\x46ilterConfigPerRoute\x12\x10\n\x08\x64isabled\x18\x01 \x01(\x08:W\x9a\xc5\x88\x1eR\nPenvoy.config.filter.http.grpc_http1_reverse_bridge.v2alpha1.FilterConfigPerRouteBa\nHio.envoyproxy.envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3B\x0b\x43onfigProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_FILTERCONFIG = _descriptor.Descriptor(
  name='FilterConfig',
  full_name='envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3.FilterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content_type', full_name='envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3.FilterConfig.content_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='withhold_grpc_frames', full_name='envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3.FilterConfig.withhold_grpc_frames', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036J\nHenvoy.config.filter.http.grpc_http1_reverse_bridge.v2alpha1.FilterConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=227,
  serialized_end=383,
)


_FILTERCONFIGPERROUTE = _descriptor.Descriptor(
  name='FilterConfigPerRoute',
  full_name='envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3.FilterConfigPerRoute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disabled', full_name='envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3.FilterConfigPerRoute.disabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036R\nPenvoy.config.filter.http.grpc_http1_reverse_bridge.v2alpha1.FilterConfigPerRoute',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=386,
  serialized_end=515,
)

DESCRIPTOR.message_types_by_name['FilterConfig'] = _FILTERCONFIG
DESCRIPTOR.message_types_by_name['FilterConfigPerRoute'] = _FILTERCONFIGPERROUTE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FilterConfig = _reflection.GeneratedProtocolMessageType('FilterConfig', (_message.Message,), {
  'DESCRIPTOR' : _FILTERCONFIG,
  '__module__' : 'envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3.FilterConfig)
  })
_sym_db.RegisterMessage(FilterConfig)

FilterConfigPerRoute = _reflection.GeneratedProtocolMessageType('FilterConfigPerRoute', (_message.Message,), {
  'DESCRIPTOR' : _FILTERCONFIGPERROUTE,
  '__module__' : 'envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3.FilterConfigPerRoute)
  })
_sym_db.RegisterMessage(FilterConfigPerRoute)


DESCRIPTOR._options = None
_FILTERCONFIG.fields_by_name['content_type']._options = None
_FILTERCONFIG._options = None
_FILTERCONFIGPERROUTE._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/rbac/v3/rbac.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.rbac.v3 import rbac_pb2 as envoy_dot_config_dot_rbac_dot_v3_dot_rbac__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/rbac/v3/rbac.proto',
  package='envoy.extensions.filters.http.rbac.v3',
  syntax='proto3',
  serialized_options=b'\n3io.envoyproxy.envoy.extensions.filters.http.rbac.v3B\tRbacProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0envoy/extensions/filters/http/rbac/v3/rbac.proto\x12%envoy.extensions.filters.http.rbac.v3\x1a\x1f\x65nvoy/config/rbac/v3/rbac.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\x91\x01\n\x04RBAC\x12)\n\x05rules\x18\x01 \x01(\x0b\x32\x1a.envoy.config.rbac.v3.RBAC\x12\x30\n\x0cshadow_rules\x18\x02 \x01(\x0b\x32\x1a.envoy.config.rbac.v3.RBAC:,\x9a\xc5\x88\x1e\'\n%envoy.config.filter.http.rbac.v2.RBAC\"\x85\x01\n\x0cRBACPerRoute\x12\x39\n\x04rbac\x18\x02 \x01(\x0b\x32+.envoy.extensions.filters.http.rbac.v3.RBAC:4\x9a\xc5\x88\x1e/\n-envoy.config.filter.http.rbac.v2.RBACPerRouteJ\x04\x08\x01\x10\x02\x42J\n3io.envoyproxy.envoy.extensions.filters.http.rbac.v3B\tRbacProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_rbac_dot_v3_dot_rbac__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_RBAC = _descriptor.Descriptor(
  name='RBAC',
  full_name='envoy.extensions.filters.http.rbac.v3.RBAC',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rules', full_name='envoy.extensions.filters.http.rbac.v3.RBAC.rules', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shadow_rules', full_name='envoy.extensions.filters.http.rbac.v3.RBAC.shadow_rules', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\'\n%envoy.config.filter.http.rbac.v2.RBAC',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=191,
  serialized_end=336,
)


_RBACPERROUTE = _descriptor.Descriptor(
  name='RBACPerRoute',
  full_name='envoy.extensions.filters.http.rbac.v3.RBACPerRoute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rbac', full_name='envoy.extensions.filters.http.rbac.v3.RBACPerRoute.rbac', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036/\n-envoy.config.filter.http.rbac.v2.RBACPerRoute',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=339,
  serialized_end=472,
)

_RBAC.fields_by_name['rules'].message_type = envoy_dot_config_dot_rbac_dot_v3_dot_rbac__pb2._RBAC
_RBAC.fields_by_name['shadow_rules'].message_type = envoy_dot_config_dot_rbac_dot_v3_dot_rbac__pb2._RBAC
_RBACPERROUTE.fields_by_name['rbac'].message_type = _RBAC
DESCRIPTOR.message_types_by_name['RBAC'] = _RBAC
DESCRIPTOR.message_types_by_name['RBACPerRoute'] = _RBACPERROUTE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RBAC = _reflection.GeneratedProtocolMessageType('RBAC', (_message.Message,), {
  'DESCRIPTOR' : _RBAC,
  '__module__' : 'envoy.extensions.filters.http.rbac.v3.rbac_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.rbac.v3.RBAC)
  })
_sym_db.RegisterMessage(RBAC)

RBACPerRoute = _reflection.GeneratedProtocolMessageType('RBACPerRoute', (_message.Message,), {
  'DESCRIPTOR' : _RBACPERROUTE,
  '__module__' : 'envoy.extensions.filters.http.rbac.v3.rbac_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.rbac.v3.RBACPerRoute)
  })
_sym_db.RegisterMessage(RBACPerRoute)


DESCRIPTOR._options = None
_RBAC._options = None
_RBACPERROUTE._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/trace/v2alpha/xray.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/trace/v2alpha/xray.proto',
  package='envoy.config.trace.v2alpha',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.config.trace.v2alphaB\tXrayProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%envoy/config/trace/v2alpha/xray.proto\x12\x1a\x65nvoy.config.trace.v2alpha\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa5\x01\n\nXRayConfig\x12\x39\n\x0f\x64\x61\x65mon_endpoint\x18\x01 \x01(\x0b\x32 .envoy.api.v2.core.SocketAddress\x12\x1d\n\x0csegment_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12=\n\x16sampling_rule_manifest\x18\x03 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB?\n(io.envoyproxy.envoy.config.trace.v2alphaB\tXrayProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_address__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_XRAYCONFIG = _descriptor.Descriptor(
  name='XRayConfig',
  full_name='envoy.config.trace.v2alpha.XRayConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='daemon_endpoint', full_name='envoy.config.trace.v2alpha.XRayConfig.daemon_endpoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='segment_name', full_name='envoy.config.trace.v2alpha.XRayConfig.segment_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampling_rule_manifest', full_name='envoy.config.trace.v2alpha.XRayConfig.sampling_rule_manifest', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=354,
)

_XRAYCONFIG.fields_by_name['daemon_endpoint'].message_type = envoy_dot_api_dot_v2_dot_core_dot_address__pb2._SOCKETADDRESS
_XRAYCONFIG.fields_by_name['sampling_rule_manifest'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
DESCRIPTOR.message_types_by_name['XRayConfig'] = _XRAYCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

XRayConfig = _reflection.GeneratedProtocolMessageType('XRayConfig', (_message.Message,), {
  'DESCRIPTOR' : _XRAYCONFIG,
  '__module__' : 'envoy.config.trace.v2alpha.xray_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.trace.v2alpha.XRayConfig)
  })
_sym_db.RegisterMessage(XRayConfig)


DESCRIPTOR._options = None
_XRAYCONFIG.fields_by_name['segment_name']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/endpoint/v3/load_report.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/endpoint/v3/load_report.proto',
  package='envoy.config.endpoint.v3',
  syntax='proto3',
  serialized_options=b'\n&io.envoyproxy.envoy.config.endpoint.v3B\017LoadReportProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*envoy/config/endpoint/v3/load_report.proto\x12\x18\x65nvoy.config.endpoint.v3\x1a\"envoy/config/core/v3/address.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb3\x03\n\x15UpstreamLocalityStats\x12\x30\n\x08locality\x18\x01 \x01(\x0b\x32\x1e.envoy.config.core.v3.Locality\x12!\n\x19total_successful_requests\x18\x02 \x01(\x04\x12\"\n\x1atotal_requests_in_progress\x18\x03 \x01(\x04\x12\x1c\n\x14total_error_requests\x18\x04 \x01(\x04\x12\x1d\n\x15total_issued_requests\x18\x08 \x01(\x04\x12L\n\x11load_metric_stats\x18\x05 \x03(\x0b\x32\x31.envoy.config.endpoint.v3.EndpointLoadMetricStats\x12P\n\x17upstream_endpoint_stats\x18\x07 \x03(\x0b\x32/.envoy.config.endpoint.v3.UpstreamEndpointStats\x12\x10\n\x08priority\x18\x06 \x01(\r:2\x9a\xc5\x88\x1e-\n+envoy.api.v2.endpoint.UpstreamLocalityStats\"\xf8\x02\n\x15UpstreamEndpointStats\x12.\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1d.envoy.config.core.v3.Address\x12)\n\x08metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12!\n\x19total_successful_requests\x18\x02 \x01(\x04\x12\"\n\x1atotal_requests_in_progress\x18\x03 \x01(\x04\x12\x1c\n\x14total_error_requests\x18\x04 \x01(\x04\x12\x1d\n\x15total_issued_requests\x18\x07 \x01(\x04\x12L\n\x11load_metric_stats\x18\x05 \x03(\x0b\x32\x31.envoy.config.endpoint.v3.EndpointLoadMetricStats:2\x9a\xc5\x88\x1e-\n+envoy.api.v2.endpoint.UpstreamEndpointStats\"\xab\x01\n\x17\x45ndpointLoadMetricStats\x12\x13\n\x0bmetric_name\x18\x01 \x01(\t\x12)\n!num_requests_finished_with_metric\x18\x02 \x01(\x04\x12\x1a\n\x12total_metric_value\x18\x03 \x01(\x01:4\x9a\xc5\x88\x1e/\n-envoy.api.v2.endpoint.EndpointLoadMetricStats\"\xfd\x03\n\x0c\x43lusterStats\x12\x1d\n\x0c\x63luster_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1c\n\x14\x63luster_service_name\x18\x06 \x01(\t\x12Z\n\x17upstream_locality_stats\x18\x02 \x03(\x0b\x32/.envoy.config.endpoint.v3.UpstreamLocalityStatsB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12\x1e\n\x16total_dropped_requests\x18\x03 \x01(\x04\x12P\n\x10\x64ropped_requests\x18\x05 \x03(\x0b\x32\x36.envoy.config.endpoint.v3.ClusterStats.DroppedRequests\x12\x37\n\x14load_report_interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x1a~\n\x0f\x44roppedRequests\x12\x19\n\x08\x63\x61tegory\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\rdropped_count\x18\x02 \x01(\x04:9\x9a\xc5\x88\x1e\x34\n2envoy.api.v2.endpoint.ClusterStats.DroppedRequests:)\x9a\xc5\x88\x1e$\n\"envoy.api.v2.endpoint.ClusterStatsBC\n&io.envoyproxy.envoy.config.endpoint.v3B\x0fLoadReportProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_address__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_UPSTREAMLOCALITYSTATS = _descriptor.Descriptor(
  name='UpstreamLocalityStats',
  full_name='envoy.config.endpoint.v3.UpstreamLocalityStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locality', full_name='envoy.config.endpoint.v3.UpstreamLocalityStats.locality', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_successful_requests', full_name='envoy.config.endpoint.v3.UpstreamLocalityStats.total_successful_requests', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_requests_in_progress', full_name='envoy.config.endpoint.v3.UpstreamLocalityStats.total_requests_in_progress', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_error_requests', full_name='envoy.config.endpoint.v3.UpstreamLocalityStats.total_error_requests', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_issued_requests', full_name='envoy.config.endpoint.v3.UpstreamLocalityStats.total_issued_requests', index=4,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_metric_stats', full_name='envoy.config.endpoint.v3.UpstreamLocalityStats.load_metric_stats', index=5,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_endpoint_stats', full_name='envoy.config.endpoint.v3.UpstreamLocalityStats.upstream_endpoint_stats', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='envoy.config.endpoint.v3.UpstreamLocalityStats.priority', index=7,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036-\n+envoy.api.v2.endpoint.UpstreamLocalityStats',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=295,
  serialized_end=730,
)


_UPSTREAMENDPOINTSTATS = _descriptor.Descriptor(
  name='UpstreamEndpointStats',
  full_name='envoy.config.endpoint.v3.UpstreamEndpointStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='envoy.config.endpoint.v3.UpstreamEndpointStats.address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='envoy.config.endpoint.v3.UpstreamEndpointStats.metadata', index=1,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_successful_requests', full_name='envoy.config.endpoint.v3.UpstreamEndpointStats.total_successful_requests', index=2,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_requests_in_progress', full_name='envoy.config.endpoint.v3.UpstreamEndpointStats.total_requests_in_progress', index=3,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_error_requests', full_name='envoy.config.endpoint.v3.UpstreamEndpointStats.total_error_requests', index=4,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_issued_requests', full_name='envoy.config.endpoint.v3.UpstreamEndpointStats.total_issued_requests', index=5,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_metric_stats', full_name='envoy.config.endpoint.v3.UpstreamEndpointStats.load_metric_stats', index=6,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036-\n+envoy.api.v2.endpoint.UpstreamEndpointStats',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=733,
  serialized_end=1109,
)


_ENDPOINTLOADMETRICSTATS = _descriptor.Descriptor(
  name='EndpointLoadMetricStats',
  full_name='envoy.config.endpoint.v3.EndpointLoadMetricStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metric_name', full_name='envoy.config.endpoint.v3.EndpointLoadMetricStats.metric_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_requests_finished_with_metric', full_name='envoy.config.endpoint.v3.EndpointLoadMetricStats.num_requests_finished_with_metric', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_metric_value', full_name='envoy.config.endpoint.v3.EndpointLoadMetricStats.total_metric_value', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036/\n-envoy.api.v2.endpoint.EndpointLoadMetricStats',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1112,
  serialized_end=1283,
)


_CLUSTERSTATS_DROPPEDREQUESTS = _descriptor.Descriptor(
  name='DroppedRequests',
  full_name='envoy.config.endpoint.v3.ClusterStats.DroppedRequests',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='category', full_name='envoy.config.endpoint.v3.ClusterStats.DroppedRequests.category', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dropped_count', full_name='envoy.config.endpoint.v3.ClusterStats.DroppedRequests.dropped_count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0364\n2envoy.api.v2.endpoint.ClusterStats.DroppedRequests',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1626,
  serialized_end=1752,
)

_CLUSTERSTATS = _descriptor.Descriptor(
  name='ClusterStats',
  full_name='envoy.config.endpoint.v3.ClusterStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_name', full_name='envoy.config.endpoint.v3.ClusterStats.cluster_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_service_name', full_name='envoy.config.endpoint.v3.ClusterStats.cluster_service_name', index=1,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_locality_stats', full_name='envoy.config.endpoint.v3.ClusterStats.upstream_locality_stats', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_dropped_requests', full_name='envoy.config.endpoint.v3.ClusterStats.total_dropped_requests', index=3,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dropped_requests', full_name='envoy.config.endpoint.v3.ClusterStats.dropped_requests', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_report_interval', full_name='envoy.config.endpoint.v3.ClusterStats.load_report_interval', index=5,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CLUSTERSTATS_DROPPEDREQUESTS, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036$\n\"envoy.api.v2.endpoint.ClusterStats',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1286,
  serialized_end=1795,
)

_UPSTREAMLOCALITYSTATS.fields_by_name['locality'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._LOCALITY
_UPSTREAMLOCALITYSTATS.fields_by_name['load_metric_stats'].message_type = _ENDPOINTLOADMETRICSTATS
_UPSTREAMLOCALITYSTATS.fields_by_name['upstream_endpoint_stats'].message_type = _UPSTREAMENDPOINTSTATS
_UPSTREAMENDPOINTSTATS.fields_by_name['address'].message_type = envoy_dot_config_dot_core_dot_v3_dot_address__pb2._ADDRESS
_UPSTREAMENDPOINTSTATS.fields_by_name['metadata'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_UPSTREAMENDPOINTSTATS.fields_by_name['load_metric_stats'].message_type = _ENDPOINTLOADMETRICSTATS
_CLUSTERSTATS_DROPPEDREQUESTS.containing_type = _CLUSTERSTATS
_CLUSTERSTATS.fields_by_name['upstream_locality_stats'].message_type = _UPSTREAMLOCALITYSTATS
_CLUSTERSTATS.fields_by_name['dropped_requests'].message_type = _CLUSTERSTATS_DROPPEDREQUESTS
_CLUSTERSTATS.fields_by_name['load_report_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['UpstreamLocalityStats'] = _UPSTREAMLOCALITYSTATS
DESCRIPTOR.message_types_by_name['UpstreamEndpointStats'] = _UPSTREAMENDPOINTSTATS
DESCRIPTOR.message_types_by_name['EndpointLoadMetricStats'] = _ENDPOINTLOADMETRICSTATS
DESCRIPTOR.message_types_by_name['ClusterStats'] = _CLUSTERSTATS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UpstreamLocalityStats = _reflection.GeneratedProtocolMessageType('UpstreamLocalityStats', (_message.Message,), {
  'DESCRIPTOR' : _UPSTREAMLOCALITYSTATS,
  '__module__' : 'envoy.config.endpoint.v3.load_report_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.endpoint.v3.UpstreamLocalityStats)
  })
_sym_db.RegisterMessage(UpstreamLocalityStats)

UpstreamEndpointStats = _reflection.GeneratedProtocolMessageType('UpstreamEndpointStats', (_message.Message,), {
  'DESCRIPTOR' : _UPSTREAMENDPOINTSTATS,
  '__module__' : 'envoy.config.endpoint.v3.load_report_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.endpoint.v3.UpstreamEndpointStats)
  })
_sym_db.RegisterMessage(UpstreamEndpointStats)

EndpointLoadMetricStats = _reflection.GeneratedProtocolMessageType('EndpointLoadMetricStats', (_message.Message,), {
  'DESCRIPTOR' : _ENDPOINTLOADMETRICSTATS,
  '__module__' : 'envoy.config.endpoint.v3.load_report_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.endpoint.v3.EndpointLoadMetricStats)
  })
_sym_db.RegisterMessage(EndpointLoadMetricStats)

ClusterStats = _reflection.GeneratedProtocolMessageType('ClusterStats', (_message.Message,), {

  'DroppedRequests' : _reflection.GeneratedProtocolMessageType('DroppedRequests', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERSTATS_DROPPEDREQUESTS,
    '__module__' : 'envoy.config.endpoint.v3.load_report_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.endpoint.v3.ClusterStats.DroppedRequests)
    })
  ,
  'DESCRIPTOR' : _CLUSTERSTATS,
  '__module__' : 'envoy.config.endpoint.v3.load_report_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.endpoint.v3.ClusterStats)
  })
_sym_db.RegisterMessage(ClusterStats)
_sym_db.RegisterMessage(ClusterStats.DroppedRequests)


DESCRIPTOR._options = None
_UPSTREAMLOCALITYSTATS._options = None
_UPSTREAMENDPOINTSTATS._options = None
_ENDPOINTLOADMETRICSTATS._options = None
_CLUSTERSTATS_DROPPEDREQUESTS.fields_by_name['category']._options = None
_CLUSTERSTATS_DROPPEDREQUESTS._options = None
_CLUSTERSTATS.fields_by_name['cluster_name']._options = None
_CLUSTERSTATS.fields_by_name['upstream_locality_stats']._options = None
_CLUSTERSTATS._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/buffer/v3/buffer.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/buffer/v3/buffer.proto',
  package='envoy.extensions.filters.http.buffer.v3',
  syntax='proto3',
  serialized_options=b'\n5io.envoyproxy.envoy.extensions.filters.http.buffer.v3B\013BufferProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4envoy/extensions/filters/http/buffer/v3/buffer.proto\x12\'envoy.extensions.filters.http.buffer.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x8a\x01\n\x06\x42uffer\x12H\n\x11max_request_bytes\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0f\xfa\x42\x04*\x02 \x00\xfa\x42\x05\x8a\x01\x02\x10\x01:0\x9a\xc5\x88\x1e+\n)envoy.config.filter.http.buffer.v2.BufferJ\x04\x08\x02\x10\x03\"\xc5\x01\n\x0e\x42ufferPerRoute\x12\x1b\n\x08\x64isabled\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12K\n\x06\x62uffer\x18\x02 \x01(\x0b\x32/.envoy.extensions.filters.http.buffer.v3.BufferB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00:8\x9a\xc5\x88\x1e\x33\n1envoy.config.filter.http.buffer.v2.BufferPerRouteB\x0f\n\x08override\x12\x03\xf8\x42\x01\x42N\n5io.envoyproxy.envoy.extensions.filters.http.buffer.v3B\x0b\x42ufferProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_BUFFER = _descriptor.Descriptor(
  name='Buffer',
  full_name='envoy.extensions.filters.http.buffer.v3.Buffer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_request_bytes', full_name='envoy.extensions.filters.http.buffer.v3.Buffer.max_request_bytes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002 \000\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036+\n)envoy.config.filter.http.buffer.v2.Buffer',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=359,
)


_BUFFERPERROUTE = _descriptor.Descriptor(
  name='BufferPerRoute',
  full_name='envoy.extensions.filters.http.buffer.v3.BufferPerRoute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disabled', full_name='envoy.extensions.filters.http.buffer.v3.BufferPerRoute.disabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004j\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buffer', full_name='envoy.extensions.filters.http.buffer.v3.BufferPerRoute.buffer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0363\n1envoy.config.filter.http.buffer.v2.BufferPerRoute',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='override', full_name='envoy.extensions.filters.http.buffer.v3.BufferPerRoute.override',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=362,
  serialized_end=559,
)

_BUFFER.fields_by_name['max_request_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_BUFFERPERROUTE.fields_by_name['buffer'].message_type = _BUFFER
_BUFFERPERROUTE.oneofs_by_name['override'].fields.append(
  _BUFFERPERROUTE.fields_by_name['disabled'])
_BUFFERPERROUTE.fields_by_name['disabled'].containing_oneof = _BUFFERPERROUTE.oneofs_by_name['override']
_BUFFERPERROUTE.oneofs_by_name['override'].fields.append(
  _BUFFERPERROUTE.fields_by_name['buffer'])
_BUFFERPERROUTE.fields_by_name['buffer'].containing_oneof = _BUFFERPERROUTE.oneofs_by_name['override']
DESCRIPTOR.message_types_by_name['Buffer'] = _BUFFER
DESCRIPTOR.message_types_by_name['BufferPerRoute'] = _BUFFERPERROUTE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Buffer = _reflection.GeneratedProtocolMessageType('Buffer', (_message.Message,), {
  'DESCRIPTOR' : _BUFFER,
  '__module__' : 'envoy.extensions.filters.http.buffer.v3.buffer_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.buffer.v3.Buffer)
  })
_sym_db.RegisterMessage(Buffer)

BufferPerRoute = _reflection.GeneratedProtocolMessageType('BufferPerRoute', (_message.Message,), {
  'DESCRIPTOR' : _BUFFERPERROUTE,
  '__module__' : 'envoy.extensions.filters.http.buffer.v3.buffer_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.buffer.v3.BufferPerRoute)
  })
_sym_db.RegisterMessage(BufferPerRoute)


DESCRIPTOR._options = None
_BUFFER.fields_by_name['max_request_bytes']._options = None
_BUFFER._options = None
_BUFFERPERROUTE.oneofs_by_name['override']._options = None
_BUFFERPERROUTE.fields_by_name['disabled']._options = None
_BUFFERPERROUTE.fields_by_name['buffer']._options = None
_BUFFERPERROUTE._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/ext_proc/v3alpha/external_processor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.extensions.filters.http.ext_proc.v3alpha import processing_mode_pb2 as envoy_dot_extensions_dot_filters_dot_http_dot_ext__proc_dot_v3alpha_dot_processing__mode__pb2
from envoy.type.v3 import http_status_pb2 as envoy_dot_type_dot_v3_dot_http__status__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/ext_proc/v3alpha/external_processor.proto',
  package='envoy.service.ext_proc.v3alpha',
  syntax='proto3',
  serialized_options=b'\n,io.envoyproxy.envoy.service.ext_proc.v3alphaB\026ExternalProcessorProtoP\001\210\001\001\272\200\310\321\006\002\010\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7envoy/service/ext_proc/v3alpha/external_processor.proto\x12\x1e\x65nvoy.service.ext_proc.v3alpha\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x44\x65nvoy/extensions/filters/http/ext_proc/v3alpha/processing_mode.proto\x1a\x1f\x65nvoy/type/v3/http_status.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xe2\x03\n\x11ProcessingRequest\x12\x12\n\nasync_mode\x18\x01 \x01(\x08\x12\x46\n\x0frequest_headers\x18\x02 \x01(\x0b\x32+.envoy.service.ext_proc.v3alpha.HttpHeadersH\x00\x12G\n\x10response_headers\x18\x03 \x01(\x0b\x32+.envoy.service.ext_proc.v3alpha.HttpHeadersH\x00\x12@\n\x0crequest_body\x18\x04 \x01(\x0b\x32(.envoy.service.ext_proc.v3alpha.HttpBodyH\x00\x12\x41\n\rresponse_body\x18\x05 \x01(\x0b\x32(.envoy.service.ext_proc.v3alpha.HttpBodyH\x00\x12H\n\x10request_trailers\x18\x06 \x01(\x0b\x32,.envoy.service.ext_proc.v3alpha.HttpTrailersH\x00\x12I\n\x11response_trailers\x18\x07 \x01(\x0b\x32,.envoy.service.ext_proc.v3alpha.HttpTrailersH\x00\x42\x0e\n\x07request\x12\x03\xf8\x42\x01\"\xc3\x05\n\x12ProcessingResponse\x12J\n\x0frequest_headers\x18\x01 \x01(\x0b\x32/.envoy.service.ext_proc.v3alpha.HeadersResponseH\x00\x12K\n\x10response_headers\x18\x02 \x01(\x0b\x32/.envoy.service.ext_proc.v3alpha.HeadersResponseH\x00\x12\x44\n\x0crequest_body\x18\x03 \x01(\x0b\x32,.envoy.service.ext_proc.v3alpha.BodyResponseH\x00\x12\x45\n\rresponse_body\x18\x04 \x01(\x0b\x32,.envoy.service.ext_proc.v3alpha.BodyResponseH\x00\x12L\n\x10request_trailers\x18\x05 \x01(\x0b\x32\x30.envoy.service.ext_proc.v3alpha.TrailersResponseH\x00\x12M\n\x11response_trailers\x18\x06 \x01(\x0b\x32\x30.envoy.service.ext_proc.v3alpha.TrailersResponseH\x00\x12O\n\x12immediate_response\x18\x07 \x01(\x0b\x32\x31.envoy.service.ext_proc.v3alpha.ImmediateResponseH\x00\x12\x31\n\x10\x64ynamic_metadata\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12U\n\rmode_override\x18\t \x01(\x0b\x32>.envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingModeB\x0f\n\x08response\x12\x03\xf8\x42\x01\"\xf3\x01\n\x0bHttpHeaders\x12\x30\n\x07headers\x18\x01 \x01(\x0b\x32\x1f.envoy.config.core.v3.HeaderMap\x12O\n\nattributes\x18\x02 \x03(\x0b\x32;.envoy.service.ext_proc.v3alpha.HttpHeaders.AttributesEntry\x12\x15\n\rend_of_stream\x18\x03 \x01(\x08\x1aJ\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:\x02\x38\x01\"/\n\x08HttpBody\x12\x0c\n\x04\x62ody\x18\x01 \x01(\x0c\x12\x15\n\rend_of_stream\x18\x02 \x01(\x08\"A\n\x0cHttpTrailers\x12\x31\n\x08trailers\x18\x01 \x01(\x0b\x32\x1f.envoy.config.core.v3.HeaderMap\"S\n\x0fHeadersResponse\x12@\n\x08response\x18\x01 \x01(\x0b\x32..envoy.service.ext_proc.v3alpha.CommonResponse\"[\n\x10TrailersResponse\x12G\n\x0fheader_mutation\x18\x01 \x01(\x0b\x32..envoy.service.ext_proc.v3alpha.HeaderMutation\"P\n\x0c\x42odyResponse\x12@\n\x08response\x18\x01 \x01(\x0b\x32..envoy.service.ext_proc.v3alpha.CommonResponse\"\xff\x02\n\x0e\x43ommonResponse\x12W\n\x06status\x18\x01 \x01(\x0e\x32=.envoy.service.ext_proc.v3alpha.CommonResponse.ResponseStatusB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12G\n\x0fheader_mutation\x18\x02 \x01(\x0b\x32..envoy.service.ext_proc.v3alpha.HeaderMutation\x12\x43\n\rbody_mutation\x18\x03 \x01(\x0b\x32,.envoy.service.ext_proc.v3alpha.BodyMutation\x12\x31\n\x08trailers\x18\x04 \x01(\x0b\x32\x1f.envoy.config.core.v3.HeaderMap\x12\x19\n\x11\x63lear_route_cache\x18\x05 \x01(\x08\"8\n\x0eResponseStatus\x12\x0c\n\x08\x43ONTINUE\x10\x00\x12\x18\n\x14\x43ONTINUE_AND_REPLACE\x10\x01\"\xe9\x01\n\x11ImmediateResponse\x12\x33\n\x06status\x18\x01 \x01(\x0b\x32\x19.envoy.type.v3.HttpStatusB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12?\n\x07headers\x18\x02 \x01(\x0b\x32..envoy.service.ext_proc.v3alpha.HeaderMutation\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12?\n\x0bgrpc_status\x18\x04 \x01(\x0b\x32*.envoy.service.ext_proc.v3alpha.GrpcStatus\x12\x0f\n\x07\x64\x65tails\x18\x05 \x01(\t\"\x1c\n\nGrpcStatus\x12\x0e\n\x06status\x18\x01 \x01(\r\"f\n\x0eHeaderMutation\x12<\n\x0bset_headers\x18\x01 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOption\x12\x16\n\x0eremove_headers\x18\x02 \x03(\t\"@\n\x0c\x42odyMutation\x12\x0e\n\x04\x62ody\x18\x01 \x01(\x0cH\x00\x12\x14\n\nclear_body\x18\x02 \x01(\x08H\x00\x42\n\n\x08mutation2\x8b\x01\n\x11\x45xternalProcessor\x12v\n\x07Process\x12\x31.envoy.service.ext_proc.v3alpha.ProcessingRequest\x1a\x32.envoy.service.ext_proc.v3alpha.ProcessingResponse\"\x00(\x01\x30\x01\x42[\n,io.envoyproxy.envoy.service.ext_proc.v3alphaB\x16\x45xternalProcessorProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,envoy_dot_extensions_dot_filters_dot_http_dot_ext__proc_dot_v3alpha_dot_processing__mode__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_http__status__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_COMMONRESPONSE_RESPONSESTATUS = _descriptor.EnumDescriptor(
  name='ResponseStatus',
  full_name='envoy.service.ext_proc.v3alpha.CommonResponse.ResponseStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONTINUE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTINUE_AND_REPLACE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2458,
  serialized_end=2514,
)
_sym_db.RegisterEnumDescriptor(_COMMONRESPONSE_RESPONSESTATUS)


_PROCESSINGREQUEST = _descriptor.Descriptor(
  name='ProcessingRequest',
  full_name='envoy.service.ext_proc.v3alpha.ProcessingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='async_mode', full_name='envoy.service.ext_proc.v3alpha.ProcessingRequest.async_mode', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers', full_name='envoy.service.ext_proc.v3alpha.ProcessingRequest.request_headers', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_headers', full_name='envoy.service.ext_proc.v3alpha.ProcessingRequest.response_headers', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_body', full_name='envoy.service.ext_proc.v3alpha.ProcessingRequest.request_body', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_body', full_name='envoy.service.ext_proc.v3alpha.ProcessingRequest.response_body', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_trailers', full_name='envoy.service.ext_proc.v3alpha.ProcessingRequest.request_trailers', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_trailers', full_name='envoy.service.ext_proc.v3alpha.ProcessingRequest.response_trailers', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request', full_name='envoy.service.ext_proc.v3alpha.ProcessingRequest.request',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=314,
  serialized_end=796,
)


_PROCESSINGRESPONSE = _descriptor.Descriptor(
  name='ProcessingResponse',
  full_name='envoy.service.ext_proc.v3alpha.ProcessingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_headers', full_name='envoy.service.ext_proc.v3alpha.ProcessingResponse.request_headers', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_headers', full_name='envoy.service.ext_proc.v3alpha.ProcessingResponse.response_headers', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_body', full_name='envoy.service.ext_proc.v3alpha.ProcessingResponse.request_body', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_body', full_name='envoy.service.ext_proc.v3alpha.ProcessingResponse.response_body', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_trailers', full_name='envoy.service.ext_proc.v3alpha.ProcessingResponse.request_trailers', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_trailers', full_name='envoy.service.ext_proc.v3alpha.ProcessingResponse.response_trailers', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='immediate_response', full_name='envoy.service.ext_proc.v3alpha.ProcessingResponse.immediate_response', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_metadata', full_name='envoy.service.ext_proc.v3alpha.ProcessingResponse.dynamic_metadata', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode_override', full_name='envoy.service.ext_proc.v3alpha.ProcessingResponse.mode_override', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='response', full_name='envoy.service.ext_proc.v3alpha.ProcessingResponse.response',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=799,
  serialized_end=1506,
)


_HTTPHEADERS_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='envoy.service.ext_proc.v3alpha.HttpHeaders.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.service.ext_proc.v3alpha.HttpHeaders.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.service.ext_proc.v3alpha.HttpHeaders.AttributesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1678,
  serialized_end=1752,
)

_HTTPHEADERS = _descriptor.Descriptor(
  name='HttpHeaders',
  full_name='envoy.service.ext_proc.v3alpha.HttpHeaders',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.service.ext_proc.v3alpha.HttpHeaders.headers', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='envoy.service.ext_proc.v3alpha.HttpHeaders.attributes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_of_stream', full_name='envoy.service.ext_proc.v3alpha.HttpHeaders.end_of_stream', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HTTPHEADERS_ATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1509,
  serialized_end=1752,
)


_HTTPBODY = _descriptor.Descriptor(
  name='HttpBody',
  full_name='envoy.service.ext_proc.v3alpha.HttpBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='body', full_name='envoy.service.ext_proc.v3alpha.HttpBody.body', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_of_stream', full_name='envoy.service.ext_proc.v3alpha.HttpBody.end_of_stream', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1754,
  serialized_end=1801,
)


_HTTPTRAILERS = _descriptor.Descriptor(
  name='HttpTrailers',
  full_name='envoy.service.ext_proc.v3alpha.HttpTrailers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trailers', full_name='envoy.service.ext_proc.v3alpha.HttpTrailers.trailers', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1803,
  serialized_end=1868,
)


_HEADERSRESPONSE = _descriptor.Descriptor(
  name='HeadersResponse',
  full_name='envoy.service.ext_proc.v3alpha.HeadersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='envoy.service.ext_proc.v3alpha.HeadersResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1870,
  serialized_end=1953,
)


_TRAILERSRESPONSE = _descriptor.Descriptor(
  name='TrailersResponse',
  full_name='envoy.service.ext_proc.v3alpha.TrailersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header_mutation', full_name='envoy.service.ext_proc.v3alpha.TrailersResponse.header_mutation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1955,
  serialized_end=2046,
)


_BODYRESPONSE = _descriptor.Descriptor(
  name='BodyResponse',
  full_name='envoy.service.ext_proc.v3alpha.BodyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='envoy.service.ext_proc.v3alpha.BodyResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2048,
  serialized_end=2128,
)


_COMMONRESPONSE = _descriptor.Descriptor(
  name='CommonResponse',
  full_name='envoy.service.ext_proc.v3alpha.CommonResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='envoy.service.ext_proc.v3alpha.CommonResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header_mutation', full_name='envoy.service.ext_proc.v3alpha.CommonResponse.header_mutation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body_mutation', full_name='envoy.service.ext_proc.v3alpha.CommonResponse.body_mutation', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trailers', full_name='envoy.service.ext_proc.v3alpha.CommonResponse.trailers', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_route_cache', full_name='envoy.service.ext_proc.v3alpha.CommonResponse.clear_route_cache', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMMONRESPONSE_RESPONSESTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2131,
  serialized_end=2514,
)


_IMMEDIATERESPONSE = _descriptor.Descriptor(
  name='ImmediateResponse',
  full_name='envoy.service.ext_proc.v3alpha.ImmediateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='envoy.service.ext_proc.v3alpha.ImmediateResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.service.ext_proc.v3alpha.ImmediateResponse.headers', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='envoy.service.ext_proc.v3alpha.ImmediateResponse.body', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc_status', full_name='envoy.service.ext_proc.v3alpha.ImmediateResponse.grpc_status', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details', full_name='envoy.service.ext_proc.v3alpha.ImmediateResponse.details', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2517,
  serialized_end=2750,
)


_GRPCSTATUS = _descriptor.Descriptor(
  name='GrpcStatus',
  full_name='envoy.service.ext_proc.v3alpha.GrpcStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='envoy.service.ext_proc.v3alpha.GrpcStatus.status', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2752,
  serialized_end=2780,
)


_HEADERMUTATION = _descriptor.Descriptor(
  name='HeaderMutation',
  full_name='envoy.service.ext_proc.v3alpha.HeaderMutation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='set_headers', full_name='envoy.service.ext_proc.v3alpha.HeaderMutation.set_headers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove_headers', full_name='envoy.service.ext_proc.v3alpha.HeaderMutation.remove_headers', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2782,
  serialized_end=2884,
)


_BODYMUTATION = _descriptor.Descriptor(
  name='BodyMutation',
  full_name='envoy.service.ext_proc.v3alpha.BodyMutation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='body', full_name='envoy.service.ext_proc.v3alpha.BodyMutation.body', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_body', full_name='envoy.service.ext_proc.v3alpha.BodyMutation.clear_body', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='mutation', full_name='envoy.service.ext_proc.v3alpha.BodyMutation.mutation',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2886,
  serialized_end=2950,
)

_PROCESSINGREQUEST.fields_by_name['request_headers'].message_type = _HTTPHEADERS
_PROCESSINGREQUEST.fields_by_name['response_headers'].message_type = _HTTPHEADERS
_PROCESSINGREQUEST.fields_by_name['request_body'].message_type = _HTTPBODY
_PROCESSINGREQUEST.fields_by_name['response_body'].message_type = _HTTPBODY
_PROCESSINGREQUEST.fields_by_name['request_trailers'].message_type = _HTTPTRAILERS
_PROCESSINGREQUEST.fields_by_name['response_trailers'].message_type = _HTTPTRAILERS
_PROCESSINGREQUEST.oneofs_by_name['request'].fields.append(
  _PROCESSINGREQUEST.fields_by_name['request_headers'])
_PROCESSINGREQUEST.fields_by_name['request_headers'].containing_oneof = _PROCESSINGREQUEST.oneofs_by_name['request']
_PROCESSINGREQUEST.oneofs_by_name['request'].fields.append(
  _PROCESSINGREQUEST.fields_by_name['response_headers'])
_PROCESSINGREQUEST.fields_by_name['response_headers'].containing_oneof = _PROCESSINGREQUEST.oneofs_by_name['request']
_PROCESSINGREQUEST.oneofs_by_name['request'].fields.append(
  _PROCESSINGREQUEST.fields_by_name['request_body'])
_PROCESSINGREQUEST.fields_by_name['request_body'].containing_oneof = _PROCESSINGREQUEST.oneofs_by_name['request']
_PROCESSINGREQUEST.oneofs_by_name['request'].fields.append(
  _PROCESSINGREQUEST.fields_by_name['response_body'])
_PROCESSINGREQUEST.fields_by_name['response_body'].containing_oneof = _PROCESSINGREQUEST.oneofs_by_name['request']
_PROCESSINGREQUEST.oneofs_by_name['request'].fields.append(
  _PROCESSINGREQUEST.fields_by_name['request_trailers'])
_PROCESSINGREQUEST.fields_by_name['request_trailers'].containing_oneof = _PROCESSINGREQUEST.oneofs_by_name['request']
_PROCESSINGREQUEST.oneofs_by_name['request'].fields.append(
  _PROCESSINGREQUEST.fields_by_name['response_trailers'])
_PROCESSINGREQUEST.fields_by_name['response_trailers'].containing_oneof = _PROCESSINGREQUEST.oneofs_by_name['request']
_PROCESSINGRESPONSE.fields_by_name['request_headers'].message_type = _HEADERSRESPONSE
_PROCESSINGRESPONSE.fields_by_name['response_headers'].message_type = _HEADERSRESPONSE
_PROCESSINGRESPONSE.fields_by_name['request_body'].message_type = _BODYRESPONSE
_PROCESSINGRESPONSE.fields_by_name['response_body'].message_type = _BODYRESPONSE
_PROCESSINGRESPONSE.fields_by_name['request_trailers'].message_type = _TRAILERSRESPONSE
_PROCESSINGRESPONSE.fields_by_name['response_trailers'].message_type = _TRAILERSRESPONSE
_PROCESSINGRESPONSE.fields_by_name['immediate_response'].message_type = _IMMEDIATERESPONSE
_PROCESSINGRESPONSE.fields_by_name['dynamic_metadata'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_PROCESSINGRESPONSE.fields_by_name['mode_override'].message_type = envoy_dot_extensions_dot_filters_dot_http_dot_ext__proc_dot_v3alpha_dot_processing__mode__pb2._PROCESSINGMODE
_PROCESSINGRESPONSE.oneofs_by_name['response'].fields.append(
  _PROCESSINGRESPONSE.fields_by_name['request_headers'])
_PROCESSINGRESPONSE.fields_by_name['request_headers'].containing_oneof = _PROCESSINGRESPONSE.oneofs_by_name['response']
_PROCESSINGRESPONSE.oneofs_by_name['response'].fields.append(
  _PROCESSINGRESPONSE.fields_by_name['response_headers'])
_PROCESSINGRESPONSE.fields_by_name['response_headers'].containing_oneof = _PROCESSINGRESPONSE.oneofs_by_name['response']
_PROCESSINGRESPONSE.oneofs_by_name['response'].fields.append(
  _PROCESSINGRESPONSE.fields_by_name['request_body'])
_PROCESSINGRESPONSE.fields_by_name['request_body'].containing_oneof = _PROCESSINGRESPONSE.oneofs_by_name['response']
_PROCESSINGRESPONSE.oneofs_by_name['response'].fields.append(
  _PROCESSINGRESPONSE.fields_by_name['response_body'])
_PROCESSINGRESPONSE.fields_by_name['response_body'].containing_oneof = _PROCESSINGRESPONSE.oneofs_by_name['response']
_PROCESSINGRESPONSE.oneofs_by_name['response'].fields.append(
  _PROCESSINGRESPONSE.fields_by_name['request_trailers'])
_PROCESSINGRESPONSE.fields_by_name['request_trailers'].containing_oneof = _PROCESSINGRESPONSE.oneofs_by_name['response']
_PROCESSINGRESPONSE.oneofs_by_name['response'].fields.append(
  _PROCESSINGRESPONSE.fields_by_name['response_trailers'])
_PROCESSINGRESPONSE.fields_by_name['response_trailers'].containing_oneof = _PROCESSINGRESPONSE.oneofs_by_name['response']
_PROCESSINGRESPONSE.oneofs_by_name['response'].fields.append(
  _PROCESSINGRESPONSE.fields_by_name['immediate_response'])
_PROCESSINGRESPONSE.fields_by_name['immediate_response'].containing_oneof = _PROCESSINGRESPONSE.oneofs_by_name['response']
_HTTPHEADERS_ATTRIBUTESENTRY.fields_by_name['value'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_HTTPHEADERS_ATTRIBUTESENTRY.containing_type = _HTTPHEADERS
_HTTPHEADERS.fields_by_name['headers'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._HEADERMAP
_HTTPHEADERS.fields_by_name['attributes'].message_type = _HTTPHEADERS_ATTRIBUTESENTRY
_HTTPTRAILERS.fields_by_name['trailers'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._HEADERMAP
_HEADERSRESPONSE.fields_by_name['response'].message_type = _COMMONRESPONSE
_TRAILERSRESPONSE.fields_by_name['header_mutation'].message_type = _HEADERMUTATION
_BODYRESPONSE.fields_by_name['response'].message_type = _COMMONRESPONSE
_COMMONRESPONSE.fields_by_name['status'].enum_type = _COMMONRESPONSE_RESPONSESTATUS
_COMMONRESPONSE.fields_by_name['header_mutation'].message_type = _HEADERMUTATION
_COMMONRESPONSE.fields_by_name['body_mutation'].message_type = _BODYMUTATION
_COMMONRESPONSE.fields_by_name['trailers'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._HEADERMAP
_COMMONRESPONSE_RESPONSESTATUS.containing_type = _COMMONRESPONSE
_IMMEDIATERESPONSE.fields_by_name['status'].message_type = envoy_dot_type_dot_v3_dot_http__status__pb2._HTTPSTATUS
_IMMEDIATERESPONSE.fields_by_name['headers'].message_type = _HEADERMUTATION
_IMMEDIATERESPONSE.fields_by_name['grpc_status'].message_type = _GRPCSTATUS
_HEADERMUTATION.fields_by_name['set_headers'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._HEADERVALUEOPTION
_BODYMUTATION.oneofs_by_name['mutation'].fields.append(
  _BODYMUTATION.fields_by_name['body'])
_BODYMUTATION.fields_by_name['body'].containing_oneof = _BODYMUTATION.oneofs_by_name['mutation']
_BODYMUTATION.oneofs_by_name['mutation'].fields.append(
  _BODYMUTATION.fields_by_name['clear_body'])
_BODYMUTATION.fields_by_name['clear_body'].containing_oneof = _BODYMUTATION.oneofs_by_name['mutation']
DESCRIPTOR.message_types_by_name['ProcessingRequest'] = _PROCESSINGREQUEST
DESCRIPTOR.message_types_by_name['ProcessingResponse'] = _PROCESSINGRESPONSE
DESCRIPTOR.message_types_by_name['HttpHeaders'] = _HTTPHEADERS
DESCRIPTOR.message_types_by_name['HttpBody'] = _HTTPBODY
DESCRIPTOR.message_types_by_name['HttpTrailers'] = _HTTPTRAILERS
DESCRIPTOR.message_types_by_name['HeadersResponse'] = _HEADERSRESPONSE
DESCRIPTOR.message_types_by_name['TrailersResponse'] = _TRAILERSRESPONSE
DESCRIPTOR.message_types_by_name['BodyResponse'] = _BODYRESPONSE
DESCRIPTOR.message_types_by_name['CommonResponse'] = _COMMONRESPONSE
DESCRIPTOR.message_types_by_name['ImmediateResponse'] = _IMMEDIATERESPONSE
DESCRIPTOR.message_types_by_name['GrpcStatus'] = _GRPCSTATUS
DESCRIPTOR.message_types_by_name['HeaderMutation'] = _HEADERMUTATION
DESCRIPTOR.message_types_by_name['BodyMutation'] = _BODYMUTATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProcessingRequest = _reflection.GeneratedProtocolMessageType('ProcessingRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSINGREQUEST,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.ProcessingRequest)
  })
_sym_db.RegisterMessage(ProcessingRequest)

ProcessingResponse = _reflection.GeneratedProtocolMessageType('ProcessingResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSINGRESPONSE,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.ProcessingResponse)
  })
_sym_db.RegisterMessage(ProcessingResponse)

HttpHeaders = _reflection.GeneratedProtocolMessageType('HttpHeaders', (_message.Message,), {

  'AttributesEntry' : _reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _HTTPHEADERS_ATTRIBUTESENTRY,
    '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.HttpHeaders.AttributesEntry)
    })
  ,
  'DESCRIPTOR' : _HTTPHEADERS,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.HttpHeaders)
  })
_sym_db.RegisterMessage(HttpHeaders)
_sym_db.RegisterMessage(HttpHeaders.AttributesEntry)

HttpBody = _reflection.GeneratedProtocolMessageType('HttpBody', (_message.Message,), {
  'DESCRIPTOR' : _HTTPBODY,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.HttpBody)
  })
_sym_db.RegisterMessage(HttpBody)

HttpTrailers = _reflection.GeneratedProtocolMessageType('HttpTrailers', (_message.Message,), {
  'DESCRIPTOR' : _HTTPTRAILERS,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.HttpTrailers)
  })
_sym_db.RegisterMessage(HttpTrailers)

HeadersResponse = _reflection.GeneratedProtocolMessageType('HeadersResponse', (_message.Message,), {
  'DESCRIPTOR' : _HEADERSRESPONSE,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.HeadersResponse)
  })
_sym_db.RegisterMessage(HeadersResponse)

TrailersResponse = _reflection.GeneratedProtocolMessageType('TrailersResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRAILERSRESPONSE,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.TrailersResponse)
  })
_sym_db.RegisterMessage(TrailersResponse)

BodyResponse = _reflection.GeneratedProtocolMessageType('BodyResponse', (_message.Message,), {
  'DESCRIPTOR' : _BODYRESPONSE,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.BodyResponse)
  })
_sym_db.RegisterMessage(BodyResponse)

CommonResponse = _reflection.GeneratedProtocolMessageType('CommonResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMMONRESPONSE,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.CommonResponse)
  })
_sym_db.RegisterMessage(CommonResponse)

ImmediateResponse = _reflection.GeneratedProtocolMessageType('ImmediateResponse', (_message.Message,), {
  'DESCRIPTOR' : _IMMEDIATERESPONSE,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.ImmediateResponse)
  })
_sym_db.RegisterMessage(ImmediateResponse)

GrpcStatus = _reflection.GeneratedProtocolMessageType('GrpcStatus', (_message.Message,), {
  'DESCRIPTOR' : _GRPCSTATUS,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.GrpcStatus)
  })
_sym_db.RegisterMessage(GrpcStatus)

HeaderMutation = _reflection.GeneratedProtocolMessageType('HeaderMutation', (_message.Message,), {
  'DESCRIPTOR' : _HEADERMUTATION,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.HeaderMutation)
  })
_sym_db.RegisterMessage(HeaderMutation)

BodyMutation = _reflection.GeneratedProtocolMessageType('BodyMutation', (_message.Message,), {
  'DESCRIPTOR' : _BODYMUTATION,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.BodyMutation)
  })
_sym_db.RegisterMessage(BodyMutation)


DESCRIPTOR._options = None
_PROCESSINGREQUEST.oneofs_by_name['request']._options = None
_PROCESSINGRESPONSE.oneofs_by_name['response']._options = None
_HTTPHEADERS_ATTRIBUTESENTRY._options = None
_COMMONRESPONSE.fields_by_name['status']._options = None
_IMMEDIATERESPONSE.fields_by_name['status']._options = None

_EXTERNALPROCESSOR = _descriptor.ServiceDescriptor(
  name='ExternalProcessor',
  full_name='envoy.service.ext_proc.v3alpha.ExternalProcessor',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2953,
  serialized_end=3092,
  methods=[
  _descriptor.MethodDescriptor(
    name='Process',
    full_name='envoy.service.ext_proc.v3alpha.ExternalProcessor.Process',
    index=0,
    containing_service=None,
    input_type=_PROCESSINGREQUEST,
    output_type=_PROCESSINGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXTERNALPROCESSOR)

DESCRIPTOR.services_by_name['ExternalProcessor'] = _EXTERNALPROCESSOR

# @@protoc_insertion_point(module_scope)
